@@ -42,8 +42,6 @@ import nom.tam.util.ArrayFuncs;
 import nom.tam.util.RandomAccess;
 import nom.tam.util.type.ElementType;
 
-import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
-
 /**
  * <p>
  * Standard image tiling implementation. FITS tiles are always 2-dimentional, but really images of any dimensions may be
@@ -129,7 +127,6 @@ public abstract class StandardImageTiler implements ImageTiler {
      * @param dims       The actual dimensions of the image.
      * @param base       The base class (should be a primitive type) of the image.
      */
-    @SuppressFBWarnings(value = "EI_EXPOSE_REP", justification = "intended exposure of mutable data")
     public StandardImageTiler(RandomAccess f, long fileOffset, int[] dims, Class<?> base) {
         randomAccessFile = f;
         this.fileOffset = fileOffset;
@@ -148,7 +145,6 @@ public abstract class StandardImageTiler implements ImageTiler {
      *
      * @throws IOException  if the underlying stream failed
      */
-    @SuppressFBWarnings(value = "RR_NOT_CHECKED", justification = "this read will never return less than the requested length")
     protected void fillFileData(Object output, long delta, int outputOffset, int segment) throws IOException {
         fillFileData(output, delta, outputOffset, segment, 1);
     }
@@ -206,7 +202,6 @@ public abstract class StandardImageTiler implements ImageTiler {
      *
      * @throws IOException if the underlying stream failed
      */
-    @SuppressFBWarnings(value = "RR_NOT_CHECKED", justification = "this read will never return less than the requested length")
     protected void fillFileData(ArrayDataOutput output, long delta, int segment) throws IOException {
         fillFileData(output, delta, segment, 1);
     }
@@ -225,7 +220,6 @@ public abstract class StandardImageTiler implements ImageTiler {
      *
      * @since              1.18
      */
-    @SuppressFBWarnings(value = "RR_NOT_CHECKED", justification = "this read will never return less than the requested length")
     protected void fillFileData(ArrayDataOutput output, long delta, int segment, int step) throws IOException {
         final int byteSize = ElementType.forClass(base).size();
 
